@@ -1,4 +1,7 @@
 /***************************************************************************
+ *   Copyright (C) 2007  Martin Meredith                                   *
+ *   mez@ubuntu.com                                                        *
+ *                                                                         *
  *   Copyright (C) 2005 by Joe Ferris                                      *
  *   jferris@optimistictech.com                                            *
  *                                                                         *
@@ -68,7 +71,7 @@ void KatapultSettings::readSettings()
 	_displayName = config->readEntry("Display", "Pure Display");
 
 	QStringList defCatalogs;
-	defCatalogs << "Program Catalog" << "Bookmark Catalog" << "Document Catalog" << "Calculator Catalog" << "Amarok Catalog" << "Spell Catalog";
+	defCatalogs << "Program Catalog" << "Bookmark Catalog" << "Document Catalog" << "Calculator Catalog" << "Amarok Catalog" << "Spell Catalog" << "Google Catalog" << "Execution Catalog";
 	_activeCatalogNames = config->readListEntry("Catalogs", defCatalogs);
 
 	// Force a config write if notification is to be shown once.
